[0.1.0]
- initial release


[0.1.1]
- added missing exports to __init__


[0.1.2]
- fixed _requests_ not being included in project dependencies
- updated pydantic to v1.9.0


[0.1.3]
- updated dependencies to use pydantic-factories 1.0.0
- added `NotFoundException`
